==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/include/x11/WSDxappDev.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDXAPPDEV_H
#define WSDXAPPDEV_H

#include <X11/Intrinsic.h>
#include <WSDappDev.h>

class WSDxappDev               :public WSDappDev {

  private:
     Display*     _disp;
     XtAppContext _app_context;
     Widget       _app_widget;
//     int*         _iprm;
//     char**       _cprm;
     XEvent*      _ev;
     GC           _gc;
     GC           _gc2;
     Atom         _accept_atom_for_sock;
     Atom         _read_event_for_execute;
  protected:

  public:
     WSDxappDev();
     virtual ~WSDxappDev();

     virtual void update();

     void setXEvent(XEvent*);
     XEvent* getEvent();

     long setInitPrm(int, char**);
virtual long handleEvents();
virtual long dispatchEvent();
virtual long initialize();
Display*       display();
Widget         appWidget();
XtAppContext   appContext();
GC             appGC();
GC             appGC2();

virtual long     getDeviceResource();
virtual long     getWindowResource();
virtual long     getContextResource();
virtual long     getSpecialResource();

virtual WSCushort getWidth();
virtual WSCushort getHeight();

    virtual long loadGuiPolicy();
    virtual long saveGuiPolicy();

//----------------------------------------------//
//饹
     WSMFclassDef(WSDxappDev,WSDappDev);
};


//Xwindow Υᥤ롼פǡܡɥץ쥹٥Ȥȯ
//ʤĥХ륭եå硢
//꡼ƤʤФʤʤ
//
extern WSDxappDev* WSGIxwinAppDev();

#endif

==> ws-v3.20-4-src.tar.gz: ws-v3.20-4/include/x11/WSDxappDev.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDXAPPDEV_H
#define WSDXAPPDEV_H

#include <X11/Intrinsic.h>
#include <WSDappDev.h>

class WSDxappDev               :public WSDappDev {

  private:
     Display*     _disp;
     XtAppContext _app_context;
     Widget       _app_widget;
//     int*         _iprm;
//     char**       _cprm;
     XEvent*      _ev;
     GC           _gc;
     GC           _gc2;
     Atom         _accept_atom_for_sock;
     Atom         _read_event_for_execute;
  protected:

  public:
     WSDxappDev();
     virtual ~WSDxappDev();

     virtual void update();

     void setXEvent(XEvent*);
     XEvent* getEvent();

     long setInitPrm(int, char**);
virtual long handleEvents();
virtual long dispatchEvent();
virtual long processEvent();
        long _dispatchEvent(WSCbool wait);
virtual long initialize();
Display*       display();
Widget         appWidget();
XtAppContext   appContext();
GC             appGC();
GC             appGC2();

virtual long     getDeviceResource();
virtual long     getWindowResource();
virtual long     getContextResource();
virtual long     getSpecialResource();

virtual WSCushort getWidth();
virtual WSCushort getHeight();

    virtual long loadGuiPolicy();
    virtual long saveGuiPolicy();

//----------------------------------------------//
     WSMFclassDef(WSDxappDev,WSDappDev);
};
extern WSDxappDev* WSGIxwinAppDev();

#endif
